@@ -1,5 +1,5 @@
 package Language::LispPerl::BuiltIns;
-$Language::LispPerl::BuiltIns::VERSION = '0.005';
+$Language::LispPerl::BuiltIns::VERSION = '0.006';
 use Moose;
 
 use Carp;
@@ -538,7 +538,7 @@ sub _impl_defmacro{
     }
     my $nast = Language::LispPerl::Atom->new({ type =>  "macro", value => $ast });
 
-    $nast->{context} = $self->evaler()->copy_current_scope();
+    $nast->context( $self->evaler()->copy_current_scope() );
 
     $self->evaler()->new_var( $name, $nast );
     return $nast;
