@@ -1,5 +1,5 @@
 package Language::LispPerl::Evaler;
-$Language::LispPerl::Evaler::VERSION = '0.005';
+$Language::LispPerl::Evaler::VERSION = '0.006';
 use Moose;
 
 use File::ShareDir;
@@ -424,7 +424,7 @@ sub bind {
         return $ast
           if $self->word_is_reserved( $name );
         my $var = $self->var($name);
-        $ast->error("unbound symbol '$var'") if !defined $var;
+        $ast->error("unbound symbol '$name'") if !defined $var;
         return $var->value();
     }
     elsif ( $type eq "symbol"
@@ -590,7 +590,7 @@ sub _eval {
             return $self->perlfunc_call( $perl_func, $meta, \@args, $ast );
         }
         elsif ( $ftype eq "macro" ) {
-            my $scope = $f->{context};
+            my $scope  = $f->context() // $self->copy_current_scope();
             my $fn    = $fvalue;
             my $fargs = $fn->third();
             my @rargs = $ast->slice( 1 .. $ast->size() - 1 );
